@@ -1,9 +1,9 @@
-# $Id$
+# $Id: Util.pm,v 1.3 2002/11/26 19:57:51 comdog Exp $
 package Mac::Path::Util;
 use strict;
 
 use base qw(Exporter);
-use vars qw(@EXPORT_OK %EXPORT_TAGS);
+use vars qw(@EXPORT_OK %EXPORT_TAGS $VERSION);
 
 use Cwd qw(getcwd);
 use Exporter;
@@ -12,6 +12,7 @@ use Exporter;
 %EXPORT_TAGS = (
 	'system' => [ qw(DARWIN MACOS) ],
 	);
+$VERSION = 0.06;
 
 my $Startup;
 
@@ -32,20 +33,23 @@ THIS IS ALPHA SOFTWARE.  SOME THINGS ARE NOT FINISHED.
 
 Convert between darwin (unix) and Mac file paths.
 
-This is not as simple as changing the directory separator.
-The Mac path has the volume name in it, whereas the darwin
-path leaves of the startup volume name because it is mounted
-as /.
+This is not as simple as changing the directory separator. The Mac path
+has the volume name in it, whereas the darwin path leaves off the
+startup volume name because it is mounted as /.  Mac::Path::Util can
+optionally use AppleScript to determine the real startup volume name
+(off by default) if you have installed Mac::AppleScript.  You can use
+this module on other platforms too.  Once the module has looked up the
+volume name, it caches it.  If you want to reset the cache, use the
+clear_startup() method.
 
 Colons ( ":" ) in the darwin path become / in the Mac path, and forward
 slashes in the Mac path become colons in the darwin path.
 
-Mac paths do not have a leading directory separator for absolute
-paths.
+Mac paths do not have a leading directory separator for absolute paths.
 
-Normally, Mac paths that end in a directory name have a trailing
-colon, but this module cannot necessarily verify that since you
-may want to convert paths.
+Normally, Mac paths that end in a directory name have a trailing colon,
+but this module cannot necessarily verify that since you may want to
+convert paths.
 
 =head2 Methods
 
@@ -65,6 +69,8 @@ use constant FALSE     => 'false';
 use constant LOCAL     => 'local';
 use constant REMOTE    => 'remote';
 
+use constant STARTUP   => 'Mac OS X Startup';
+
 =item new( PATH [, HASH ] )
 
 
@@ -72,7 +78,7 @@ The optional anonymous hash can have these values:
 
 	type      DARWIN or MACOS (explicitly state which sort of path
                  with these symbolic constants)
-	startup   the name of the startup volume (if not defined, uses
+	startup   the name of the startup volume (if not defined, tries to use
                  the startup volume on the local machine)
 
 =cut
@@ -87,11 +93,11 @@ sub new
 		unless ( $args->{type} eq DARWIN or $args->{type} eq MACOS );
 
 	my $self = {
-		starting_path => $path,
-		type          => $type,
-		path          => $path,
+		starting_path  => $path,
+		type           => $type,
+		path           => $path,
 		};
-
+	
 	bless $self, $class;
 
 	$self->{startup} = $args->{startup} || undef;
@@ -161,14 +167,38 @@ sub new
 
 =item darwin_path
 
+=back
+
 =cut
 
-sub type        { return $_[0]->{type}        }
-sub path        { return $_[0]->{path}        }
-sub volume      { return $_[0]->{volume}      }
-sub startup     { return $_[0]->{startup}     }
-sub mac_path    { return $_[0]->{mac_path}    }
-sub darwin_path { return $_[0]->{darwin_path} }
+sub type            { return $_[0]->{type}        }
+sub path            { return $_[0]->{path}        }
+sub volume          { return $_[0]->{volume}      }
+sub startup         { return $_[0]->{startup}     }
+sub mac_path        { return $_[0]->{mac_path}    }
+sub darwin_path     { return $_[0]->{darwin_path} }
+
+=head2 Setter methods
+
+=over 4
+
+=item use_applescript( [ TRUE | FALSE ] )
+
+Mac::Path::Util will try to use AppleScript to determine the real
+startup volume name if you pass this method a true value and you
+have Mac::AppleScript installed.  Otherwise it will use the default
+startup volume name.
+
+=cut
+
+sub use_applescript 
+	{ 
+	my $self = shift;
+	
+	$self->{use_applescript} = $_[0] ? 1 : 0;
+	
+	$self->clear_startup
+	}
 
 sub _d2m_trans
 	{
@@ -256,6 +286,13 @@ sub _identify
 
 	}
 
+=item clear_startup
+
+Clear the cached startup volume name.  The next lookup will
+reset the cache.
+
+=cut
+
 sub clear_startup
 	{
 	my $self = shift;
@@ -271,18 +308,23 @@ sub _get_startup
 	return $self->startup if defined $self->startup;
 	return $Startup if defined $Startup;
 
-	return unless eval { require Mac::AppleScript };
-
-	my $script = <<"SCRIPT";
-tell application "Finder"
-	set myDisks to every disk where startup is true
-	return name of item 1 of myDisks
-end tell
-SCRIPT
-
-	my $volume = Mac::AppleScript::RunAppleScript( $script );
-	$volume =~ s/^"|"$//g;
-
+	my $volume = do {
+		if( $self->{use_applescript} and eval { require Mac::AppleScript } )
+			{
+	
+			my $script = "return path to startup disk as string";
+	
+			my $volume = Mac::AppleScript::RunAppleScript( $script );
+			$volume =~ s/^"|"$//g;
+			$volume =~ s/:$//g;
+			$volume;
+			}
+		else
+			{
+			STARTUP;
+			}
+		};
+		
 	#print STDERR "I think the startup volume is [$volume]\n";
 
 	$Startup = $self->{startup} = $volume;
@@ -297,30 +339,26 @@ sub _is_startup
 
 	$name =~ s/"/\\"/g;
 
-	return unless eval { require Mac::AppleScript };
-
-	my $script = <<"SCRIPT";
-tell application "Finder"
-	set myTry to "$name"
-	set myDisks to every disk where startup is true
-	set myName to name of item 1 of myDisks
-	return myTry is myName
-end tell
-SCRIPT
-
-	my $volume = Mac::AppleScript::RunAppleScript( $script );
-	$volume =~ s/^"|"$//g;
-
-	#print STDERR "I think the startup volume is [$volume]\n";
-
-	return $volume;
+	$self->_get_startup unless defined $self->startup;
+	
+	$name eq $Startup ? TRUE : FALSE;
 	}
 
 =back
 
+=head1 SOURCE AVAILABILITY
+
+This source is part of a SourceForge project which always has the
+latest sources in CVS, as well as all of the previous releases.
+
+	https://sourceforge.net/projects/brian-d-foy/
+	
+If, for some reason, I disappear from the world, one of the other
+members of the project can shepherd this module appropriately.
+
 =head1 AUTHOR
 
-brian d foy, E<gt>bdfoy@cpan.orgE<gt>
+brian d foy, E<lt>bdfoy@cpan.orgE<gt>
 
 =head1 COPYRIGHT
 
